==> kakikoMap-1.0.0.tar.gz: kakikoMap/kakikolib/class/db/tabledata/BaseMapData.class.php <==
<?php

//このソースは自動生成しています。バージョン、パッケージ情報など「XX」と記載されている部分を適宜修正してください。
/**
* BaseMapData.class.php 処理概要:BaseMapDataデータクラス
* PHP versions：4.4.XX
* @パッケージ：XX
* @作者：K.Shimomura
* @作成日/作成者：2006/09/01 K.Shimomura
* @更新日/更新者：
* @バージョン：XX.XX
*
* Copyright (c) 2006 Iwate Information System Co.,Ltd. All Rights Reserved.       
* You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese). 
*/
class BaseMapData{

	//クラス変数 
	var $directryName;
	var $useGIS;
	var $startX;
	var $startY;
	var $endX;
	var $endY;
	var $mapSizeHorizontal;
	var $mapSizeVertical;
	var $moveMapSphere;
	var $diffX;
	var $diffY;
	var $addDateTime;
	var $updateDateTime;

	/**
	* 関数名：コンストラクタ
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function BaseMapData(){
		$this->directryName = null;
		$this->useGIS = null;
		$this->startX = 0.0;
		$this->startY = 0.0;
		$this->endX = 0.0;
		$this->endY = 0.0;
		$this->mapSizeHorizontal = 0;
		$this->mapSizeVertical = 0;
		$this->diffX = 0.0;
		$this->diffY = 0.0;
		$this->moveMapSphere = null;
		$this->addDateTime = null;
		$this->updateDateTime = null;
	}

	//SETTER
	/**
	* 関数名：ディレクトリ名称設定
	* @引数：(I) $directryName	- ディレクトリ名称
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDirectryName($directryName){
		$this->directryName = $directryName;
	}

	/**
	* 関数名：GIS有無区分設定
	* @引数：(I) $useGIS	- GIS有無区分
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setUseGIS($useGIS){
		$this->useGIS = $useGIS;
	}

	/**
	* 関数名：始点X設定
	* @引数：(I) $startX	- 始点X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setStartX($startX){
		$this->startX = $startX;
	}

	/**
	* 関数名：始点Y設定
	* @引数：(I) $startY	- 始点Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setStartY($startY){
		$this->startY = $startY;
	}

	/**
	* 関数名：終点X設定
	* @引数：(I) $endX	- 終点X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setEndX($endX){
		$this->endX = $endX;
	}

	/**
	* 関数名：終点Y設定
	* @引数：(I) $endY	- 終点Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setEndY($endY){
		$this->endY = $endY;
	}

	/**
	* 関数名：地図サイズ横設定
	* @引数：(I) $mapSizeHorizontal	- 地図サイズ横
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMapSizeHorizontal($mapSizeHorizontal){
		$this->mapSizeHorizontal = $mapSizeHorizontal;
	}

	/**
	* 関数名：地図サイズ縦設定
	* @引数：(I) $mapSizeVertical	- 地図サイズ縦
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMapSizeVertical($mapSizeVertical){
		$this->mapSizeVertical = $mapSizeVertical;
	}

	/**
	* 関数名：差分X設定
	* @引数：(I) $diffX	- 差分X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDiffX($diffX){
		$this->diffX = $diffX;
	}

	/**
	* 関数名：差分Y設定
	* @引数：(I) $diffY	- 差分Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDiffY($diffY){
		$this->diffY = $diffY;
	}

	/**
	* 関数名：地図移動範囲設定
	* @引数：(I) $moveMapSphere	- 地図移動範囲
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMoveMapSphere($moveMapSphere){
		$this->moveMapSphere = $moveMapSphere;
	}

	/**
	* 関数名：登録日時設定
	* @引数：(I) $addDateTime	- 登録日時
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setAddDateTime($addDateTime){
		$this->addDateTime = $addDateTime;
	}

	/**
	* 関数名：更新日時設定
	* @引数：(I) $updateDateTime	- 更新日時
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setUpdateDateTime($updateDateTime){
		$this->updateDateTime = $updateDateTime;
	}


	//GETTER
	/**
	* 関数名：ディレクトリ名称取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDirectryName(){
		return $this->directryName;
	}

	/**
	* 関数名：GIS有無区分取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getUseGIS(){
		return $this->useGIS;
	}

	/**
	* 関数名：始点X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getStartX(){
		return $this->startX;
	}

	/**
	* 関数名：始点Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getStartY(){
		return $this->startY;
	}

	/**
	* 関数名：終点X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getEndX(){
		return $this->endX;
	}

	/**
	* 関数名：終点Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getEndY(){
		return $this->endY;
	}

	/**
	* 関数名：地図サイズ横取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMapSizeHorizontal(){
		return $this->mapSizeHorizontal;
	}

	/**
	* 関数名：地図サイズ縦取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMapSizeVertical(){
		return $this->mapSizeVertical;
	}

	/**
	* 関数名：差分X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDiffX(){
		return $this->diffX;
	}

	/**
	* 関数名：差分Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDiffY(){
		return $this->diffY;
	}

	/**
	* 関数名：地図移動範囲取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMoveMapSphere(){
		return $this->moveMapSphere;
	}

	/**
	* 関数名：登録日時取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getAddDateTime(){
		return $this->addDateTime;
	}

	/**
	* 関数名：更新日時取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getUpdateDateTime(){
		return $this->updateDateTime;
	}

}
?>

==> kakikoMap-1.1.0.tar.gz: kakikoMap/kakikolib/class/db/tabledata/BaseMapData.class.php <==
<?php

/**
* BaseMapData.class.php 処理概要:BaseMapDataデータクラス
* PHP versions：4.4.2
* @パッケージ：XX
* @作者：K.Shimomura
* @作成日/作成者：2006/09/01 K.Shimomura
* @更新日/更新者：2007/03/01 (IIS) N.Soma 携帯機能追加
* @バージョン：1.1.0
*
* Copyright (c) 2006-2007 Iwate Information System Co.,Ltd. All Rights Reserved.       
* You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese). 
*/
class BaseMapData{

	//クラス変数 
	var $directryName;
	var $useGIS;
	var $startX;
	var $startY;
	var $endX;
	var $endY;
	var $mapSizeHorizontal;
	var $mapSizeVertical;
	var $moveMapSphere;
	var $diffX;
	var $diffY;
	var $addDateTime;
	var $updateDateTime;
	var $mapSizeHorizontalMobile;
	var $mapSizeVerticalMobile;
	var $diffXMobile;
	var $diffYMobile;

	/**
	* 関数名：コンストラクタ
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：2007/03/01 (IIS) N.Soma 携帯機能追加
	*/
	function BaseMapData(){
		$this->directryName = null;
		$this->useGIS = null;
		$this->startX = 0.0;
		$this->startY = 0.0;
		$this->endX = 0.0;
		$this->endY = 0.0;
		$this->mapSizeHorizontal = 0;
		$this->mapSizeVertical = 0;
		$this->diffX = 0.0;
		$this->diffY = 0.0;
		$this->moveMapSphere = null;
		$this->addDateTime = null;
		$this->updateDateTime = null;
		$this->mapSizeHorizontalMobile = 0;
		$this->mapSizeVerticalMobile = 0;
		$this->diffXMobile = 0.0;
		$this->diffYMobile = 0.0;
	}

	//SETTER
	/**
	* 関数名：ディレクトリ名称設定
	* @引数：(I) $directryName	- ディレクトリ名称
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDirectryName($directryName){
		$this->directryName = $directryName;
	}

	/**
	* 関数名：GIS有無区分設定
	* @引数：(I) $useGIS	- GIS有無区分
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setUseGIS($useGIS){
		$this->useGIS = $useGIS;
	}

	/**
	* 関数名：始点X設定
	* @引数：(I) $startX	- 始点X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setStartX($startX){
		$this->startX = $startX;
	}

	/**
	* 関数名：始点Y設定
	* @引数：(I) $startY	- 始点Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setStartY($startY){
		$this->startY = $startY;
	}

	/**
	* 関数名：終点X設定
	* @引数：(I) $endX	- 終点X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setEndX($endX){
		$this->endX = $endX;
	}

	/**
	* 関数名：終点Y設定
	* @引数：(I) $endY	- 終点Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setEndY($endY){
		$this->endY = $endY;
	}

	/**
	* 関数名：地図サイズ横設定
	* @引数：(I) $mapSizeHorizontal	- 地図サイズ横
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMapSizeHorizontal($mapSizeHorizontal){
		$this->mapSizeHorizontal = $mapSizeHorizontal;
	}

	/**
	* 関数名：地図サイズ縦設定
	* @引数：(I) $mapSizeVertical	- 地図サイズ縦
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMapSizeVertical($mapSizeVertical){
		$this->mapSizeVertical = $mapSizeVertical;
	}

	/**
	* 関数名：差分X設定
	* @引数：(I) $diffX	- 差分X
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDiffX($diffX){
		$this->diffX = $diffX;
	}

	/**
	* 関数名：差分Y設定
	* @引数：(I) $diffY	- 差分Y
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setDiffY($diffY){
		$this->diffY = $diffY;
	}

	/**
	* 関数名：地図移動範囲設定
	* @引数：(I) $moveMapSphere	- 地図移動範囲
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setMoveMapSphere($moveMapSphere){
		$this->moveMapSphere = $moveMapSphere;
	}

	/**
	* 関数名：登録日時設定
	* @引数：(I) $addDateTime	- 登録日時
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setAddDateTime($addDateTime){
		$this->addDateTime = $addDateTime;
	}

	/**
	* 関数名：更新日時設定
	* @引数：(I) $updateDateTime	- 更新日時
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function setUpdateDateTime($updateDateTime){
		$this->updateDateTime = $updateDateTime;
	}

	/**
	* 関数名：携帯地図サイズ横設定
	* @引数：(I) $mapSizeHorizontalMobile	- 地図サイズ横
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function setMapSizeHorizontalMobile($mapSizeHorizontalMobile){
		$this->mapSizeHorizontalMobile = $mapSizeHorizontalMobile;
	}

	/**
	* 関数名：携帯地図サイズ縦設定
	* @引数：(I) $mapSizeVerticalMobile	- 地図サイズ縦
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function setMapSizeVerticalMobile($mapSizeVerticalMobile){
		$this->mapSizeVerticalMobile = $mapSizeVerticalMobile;
	}

	/**
	* 関数名：携帯差分X設定
	* @引数：(I) $diffX	- 差分X
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function setDiffXMobile($diffXMobile){
		$this->diffXMobile = $diffXMobile;
	}

	/**
	* 関数名：携帯差分Y設定
	* @引数：(I) $diffY	- 差分Y
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function setDiffYMobile($diffYMobile){
		$this->diffYMobile = $diffYMobile;
	}


	//GETTER
	/**
	* 関数名：ディレクトリ名称取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDirectryName(){
		return $this->directryName;
	}

	/**
	* 関数名：GIS有無区分取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getUseGIS(){
		return $this->useGIS;
	}

	/**
	* 関数名：始点X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getStartX(){
		return $this->startX;
	}

	/**
	* 関数名：始点Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getStartY(){
		return $this->startY;
	}

	/**
	* 関数名：終点X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getEndX(){
		return $this->endX;
	}

	/**
	* 関数名：終点Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getEndY(){
		return $this->endY;
	}

	/**
	* 関数名：地図サイズ横取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMapSizeHorizontal(){
		return $this->mapSizeHorizontal;
	}

	/**
	* 関数名：地図サイズ縦取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMapSizeVertical(){
		return $this->mapSizeVertical;
	}

	/**
	* 関数名：差分X取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDiffX(){
		return $this->diffX;
	}

	/**
	* 関数名：差分Y取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getDiffY(){
		return $this->diffY;
	}

	/**
	* 関数名：地図移動範囲取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getMoveMapSphere(){
		return $this->moveMapSphere;
	}

	/**
	* 関数名：登録日時取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getAddDateTime(){
		return $this->addDateTime;
	}

	/**
	* 関数名：更新日時取得
	* @引数：なし
	* @作成日/作成者：2006/09/01 K.Shimomura
	* @更新日/更新者：
	*/
	function getUpdateDateTime(){
		return $this->updateDateTime;
	}

	/**
	* 関数名：携帯地図サイズ横取得
	* @引数：なし
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function getMapSizeHorizontalMobile(){
		return $this->mapSizeHorizontalMobile;
	}

	/**
	* 関数名：携帯地図サイズ縦取得
	* @引数：なし
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function getMapSizeVerticalMobile(){
		return $this->mapSizeVerticalMobile;
	}

	/**
	* 関数名：携帯差分X取得
	* @引数：なし
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function getDiffXMobile(){
		return $this->diffXMobile;
	}

	/**
	* 関数名：携帯差分Y取得
	* @引数：なし
	* @作成日/作成者：2007/03/01 (IIS) N.Soma
	* @更新日/更新者：
	*/
	function getDiffYMobile(){
		return $this->diffYMobile;
	}

}
?>
